@@ -4,7 +4,6 @@
 
 set -e
 
-unset OPENSHIFT_BUILD_NAMESPACE
 source hack/common.sh
 source hack/operator-sdk-common.sh
 
@@ -41,14 +40,12 @@ function dump_noobaa_csv() {
 	rm -rf $noobaa_crds_outdir
 	mkdir -p $noobaa_crds_outdir
 
-	${OC_TOOL} delete pod cpaas-noobaa || true
-	(${OC_TOOL} run cpaas-noobaa -i -t --quiet=true --restart="Never" --image="${NOOBAA_OPERATOR_IMAGE_PULL_URL}" \
-		--command /usr/local/bin/noobaa-operator $noobaa_dump_csv_cmd) > $NOOBAA_CSV
-	${OC_TOOL} delete pod cpaas-noobaa
-	${OC_TOOL} delete pod cpaas-noobaa2 || true
-	(${OC_TOOL} run cpaas-noobaa2 -i -t --quiet=true --restart="Never" --image="${NOOBAA_OPERATOR_IMAGE_PULL_URL}" \
-		--command /usr/local/bin/noobaa-operator $noobaa_dump_crds_cmd) > $noobaa_crds_outdir/noobaa-crd.yaml
-	${OC_TOOL} delete pod cpaas-noobaa2
+	echo "Dumping Noobaa csv and crds"
+	${OCS_OC_PATH} image extract --confirm "${NOOBAA_IMAGE}" --path /usr/local/bin/noobaa-operator:./
+	chmod +x ./noobaa-operator
+	./noobaa-operator $noobaa_dump_csv_cmd > $NOOBAA_CSV
+	./noobaa-operator $noobaa_dump_crds_cmd > $noobaa_crds_outdir/noobaa-crd.yaml
+	rm -f ./noobaa-operator
 }
 
 # ==== DUMP ROOK YAMLS ====
@@ -64,17 +61,11 @@ function dump_rook_csv() {
 
 	temp_dir=$(mktemp -d)
 
-	${OC_TOOL} delete pod cpaas-rook || true
-	${OC_TOOL} run cpaas-rook --image=${ROOK_CEPH_OPERATOR_IMAGE_PULL_URL} --command sleep 60
-	for i in $(seq 1 30); do
-		${OC_TOOL} rsync cpaas-rook:${rook_template_dir_parent}/${rook_template_dir} ${temp_dir} && break || true
-		echo "Waiting for pod..."
-		sleep 10
-	done
-	${OC_TOOL} delete pod cpaas-rook
+	echo "Dumping rook csv and crds"
+	${OCS_OC_PATH} image extract ${ROOK_IMAGE} --path ${rook_template_dir_parent}/${rook_template_dir}:${temp_dir}
 
 	if [ -z "$(ls -A ${temp_dir})" ]; then
-		echo "[FATAL] Failed to fetch template dir from Rook pod"
+		echo "[FATAL] Failed to extract template dir from Rook image"
 		rm -rf ${temp_dir}
 		exit 1
 	fi
